********
Overview
********

.. The goal of this document is to provide an overview of the content present in the user guide.
.. It is not meant to replace the general getting started or duplicate the content in the user guide
.. sections.

In this guide, we explain the concepts of Oríon in depth. A light weight introduction is available
in :doc:`/install/gettingstarted` to familiarize yourself with the project and its concepts.

The user guide is organized in the following sections:

* :doc:`/user/script`. Describes how you can integrate Oríon to your existing scripts and
  experiments.
* :doc:`/user/api`. Describes how to start and configure hyperparameter optimizations.
* :doc:`/user/algorithms`. Describes our optimization algorithms and their options.
* :doc:`/user/searchspace`. Describes our search space and their options.
* :doc:`/user/monitoring`. Describes how to observe trials and view experiments results.
* :doc:`/user/evc`. Describes how trials are organized and how you can reuse results from past
  experiments.
* :doc:`/user/storage`. Describes how to interact with the experiment database directly.
* :doc:`/user/config`. Details in depth how the configuration system works.
* :doc:`/user/parallel`. Describes how to run multiple workers for the same experiment.

If you have any questions or feel something is missing in the documentation, always feel free to
start a `new issue <https://github.com/Epistimio/orion/issues/new>`_ and tell us!
